import { ObservableHttp } from "./harness";
/**
 * Wrapped http services as a common interface.
 * HttpHarness allows you to separate a DI process and a http process.
 *
 *
 * ## Shared code: `TestService` as an abstract class
 *
 * ```
 * export abstract class TestService {
 *    private http: HttpHarness;
 *
 *    constructor(http: HttpHarness) {
 *        this.http = http;
 *    }
 *
 *    get(id: string): Observable<any> {
 *        return this.http.get(`/${id}`);
 *    }
 * }
 * ```
 *
 * ## Angular 1 code: `Ng1TestService` as an entry point for `$http`
 * Use `angular-http-harness/ng1`
 *
 * ```
 * import {HttpHarness} from "angular-http-harness";
 * import {fromNg1} from "angular-http-harness/ng1";
 *
 * export class Ng1TestService extends TestService {
 *
 *     constructor($http: angular.IHttpService) {
 *         super(new HttpHarness(fromNg1($http)));
 *     }
 *
 *     get(id: string): Observable<TestModel> {
 *         return super.get(id).map(resp => resp.data);
 *     }
 * }
 *
 * angular.module("app").service("testService", ["$http", Ng1TestService]);
 * ```
 *
 */
export declare function fromNg1($http: angular.IHttpService): ObservableHttp;
